X-Git-Url: https://git.rapsys.eu/userbundle/blobdiff_plain/059c240bf49d573e9f1e7dc173292224de7c2b3c..77f2fa1cc42a396ab328b9ac2dea3dfe6a6868b4:/DependencyInjection/Configuration.php

diff --git a/DependencyInjection/Configuration.php b/DependencyInjection/Configuration.php
index 4d2d3bf..7c053c9 100644
--- a/DependencyInjection/Configuration.php
+++ b/DependencyInjection/Configuration.php
@@ -1,7 +1,7 @@
 <?php declare(strict_types=1);
 
 /*
- * This file is part of the Rapsys PackBundle package.
+ * This file is part of the Rapsys UserBundle package.
  *
  * (c) Raphaël Gertz <symfony@rapsys.eu>
  *
@@ -14,10 +14,12 @@ namespace Rapsys\UserBundle\DependencyInjection;
 use Symfony\Component\Config\Definition\Builder\TreeBuilder;
 use Symfony\Component\Config\Definition\ConfigurationInterface;
 
+use Rapsys\UserBundle\RapsysUserBundle;
+
 /**
  * This is the class that validates and merges configuration from your app/config files.
  *
- * @link http://symfony.com/doc/current/cookbook/bundles/configuration.html}
+ * @link http://symfony.com/doc/current/cookbook/bundles/configuration.html
  *
  * {@inheritdoc}
  */
@@ -27,60 +29,71 @@ class Configuration implements ConfigurationInterface {
 	 */
 	public function getConfigTreeBuilder(): TreeBuilder {
 		//Set tree builder
-		$treeBuilder = new TreeBuilder('rapsys_user');
+		$treeBuilder = new TreeBuilder(RapsysUserBundle::getAlias());
 
 		//The bundle default values
 		$defaults = [
 			'class' => [
-				'group' => 'Rapsys\\UserBundle\\Entity\\Group',
 				'civility' => 'Rapsys\\UserBundle\\Entity\\Civility',
+				'group' => 'Rapsys\\UserBundle\\Entity\\Group',
 				'user' => 'Rapsys\\UserBundle\\Entity\\User'
 			],
 			'default' => [
+				'admin' => 'ROLE_ADMIN',
 				'civility' => 'Mister',
+				'languages' => [
+					'en_gb' => 'English'
+				],
+				'locales' => [ 'en_gb' ],
 				'group' => [ 'User' ]
 			],
 			'route' => [
 				'confirm' => [
-					'name' => 'rapsys_user_confirm',
+					'name' => 'rapsysuser_confirm',
 					'context' => []
 				],
 				'edit' => [
-					'name' => 'rapsys_user_edit',
+					'name' => 'rapsysuser_edit',
 					'context' => []
 				],
 				'index' => [
-					'name' => 'rapsys_user_index',
+					'name' => 'rapsysuser_index',
 					'context' => []
 				],
 				'login' => [
-					'name' => 'rapsys_user_login',
+					'name' => 'rapsysuser_login',
 					'context' => []
 				],
 				'recover' => [
-					'name' => 'rapsys_user_recover',
+					'name' => 'rapsysuser_recover',
 					'context' => []
 				],
 				'register' => [
-					'name' => 'rapsys_user_register',
+					'name' => 'rapsysuser_register',
 					'context' => []
 				]
 			],
 			'translate' => [],
-			'locales' => '%kernel.translator.fallbacks%',
-			'languages' => [
-				'en_gb' => 'English'
-			],
 			'contact' => [
-				'title' => 'John Doe',
-				'mail' => 'contact@example.com'
+				'address' => 'contact@example.com',
+				'name' => 'John Doe'
 			],
 			'context' => [],
 			'edit' => [
+				'admin' => ['mail' => true, 'pseudonym' => true],
+				'field' => [],
 				'route' => ['index' => 'index_url'],
 				'view' => [
-					'form' => 'Rapsys\UserBundle\Form\RegisterType',
 					'name' => '@RapsysUser/form/register.html.twig',
+					'edit' => 'Rapsys\UserBundle\Form\EditType',
+					'reset' => 'Rapsys\UserBundle\Form\ResetType',
+					'context' => []
+				]
+			],
+			'index' => [
+				'route' => ['index' => 'index_url'],
+				'view' => [
+					'name' => '@RapsysUser/form/index.html.twig',
 					'context' => []
 				]
 			],
@@ -107,10 +120,12 @@ class Configuration implements ConfigurationInterface {
 				]
 			],
 			'register' => [
+				'admin' => [],
+				'field' => [],
 				'route' => ['index' => 'index_url', 'confirm' => 'confirm_url'],
 				'view' => [
-					'form' => 'Rapsys\UserBundle\Form\RegisterType',
 					'name' => '@RapsysUser/form/register.html.twig',
+					'form' => 'Rapsys\UserBundle\Form\RegisterType',
 					'context' => []
 				],
 				'mail' => [
@@ -129,8 +144,8 @@ class Configuration implements ConfigurationInterface {
 		 * @link http://symfony.com/doc/current/components/config/definition.html
 		 * @link https://github.com/symfony/assetic-bundle/blob/master/DependencyInjection/Configuration.php#L63
 		 *
 		 * @see php bin/console config:dump-reference rapsys_user to dump default config
 		 * @see php bin/console debug:config rapsys_user to dump config
 		 */
 		$treeBuilder
 			//Parameters
@@ -138,14 +153,34 @@ class Configuration implements ConfigurationInterface {
 				->addDefaultsIfNotSet()
 				->children()
 					->arrayNode('class')
-						->treatNullLike([])
-						->defaultValue($defaults['class'])
-						->scalarPrototype()->end()
+						->addDefaultsIfNotSet()
+						#XXX: ignoreExtraKeys(bool $remove = true)
+						->ignoreExtraKeys(false)
+						->children()
+							->scalarNode('civility')->cannotBeEmpty()->defaultValue($defaults['class']['civility'])->end()
+							->scalarNode('group')->cannotBeEmpty()->defaultValue($defaults['class']['group'])->end()
+							->scalarNode('user')->cannotBeEmpty()->defaultValue($defaults['class']['user'])->end()
+						->end()
 					->end()
 					->arrayNode('default')
 						->addDefaultsIfNotSet()
+						#XXX: ignoreExtraKeys(bool $remove = true)
+						->ignoreExtraKeys(false)
 						->children()
+							->scalarNode('admin')->cannotBeEmpty()->defaultValue($defaults['default']['admin'])->end()
 							->scalarNode('civility')->cannotBeEmpty()->defaultValue($defaults['default']['civility'])->end()
+							#TODO: see if we can't prevent key normalisation with ->normalizeKeys(false)
+							->arrayNode('languages')
+								->treatNullLike([])
+								->defaultValue($defaults['default']['languages'])
+								->scalarPrototype()->end()
+							->end()
+							#TODO: see if we can't prevent key normalisation with ->normalizeKeys(false)
+							->arrayNode('locales')
+								->treatNullLike([])
+								->defaultValue($defaults['default']['locales'])
+								->scalarPrototype()->end()
+							->end()
 							->arrayNode('group')
 								->treatNullLike([])
 								->defaultValue($defaults['default']['group'])
@@ -229,17 +264,11 @@ class Configuration implements ConfigurationInterface {
 						->defaultValue($defaults['translate'])
 						->scalarPrototype()->end()
 					->end()
-					->scalarNode('locales')->cannotBeEmpty()->defaultValue($defaults['locales'])->end()
-					->arrayNode('languages')
-						->treatNullLike([])
-						->defaultValue($defaults['languages'])
-						->scalarPrototype()->end()
-					->end()
 					->arrayNode('contact')
 						->addDefaultsIfNotSet()
 						->children()
-							->scalarNode('title')->cannotBeEmpty()->defaultValue($defaults['contact']['title'])->end()
-							->scalarNode('mail')->cannotBeEmpty()->defaultValue($defaults['contact']['mail'])->end()
+							->scalarNode('address')->cannotBeEmpty()->defaultValue($defaults['contact']['address'])->end()
+							->scalarNode('name')->cannotBeEmpty()->defaultValue($defaults['contact']['name'])->end()
 						->end()
 					->end()
 					->arrayNode('context')
@@ -250,6 +279,16 @@ class Configuration implements ConfigurationInterface {
 					->arrayNode('edit')
 						->addDefaultsIfNotSet()
 						->children()
+							->arrayNode('admin')
+								->treatNullLike([])
+								->defaultValue($defaults['edit']['admin'])
+								->variablePrototype()->end()
+							->end()
+							->arrayNode('field')
+								->treatNullLike([])
+								->defaultValue($defaults['edit']['field'])
+								->variablePrototype()->end()
+							->end()
 							->arrayNode('route')
 								->treatNullLike([])
 								->defaultValue($defaults['edit']['route'])
@@ -258,7 +297,8 @@ class Configuration implements ConfigurationInterface {
 							->arrayNode('view')
 								->addDefaultsIfNotSet()
 								->children()
-									->scalarNode('form')->cannotBeEmpty()->defaultValue($defaults['edit']['view']['form'])->end()
+									->scalarNode('edit')->cannotBeEmpty()->defaultValue($defaults['edit']['view']['edit'])->end()
+									->scalarNode('reset')->cannotBeEmpty()->defaultValue($defaults['edit']['view']['reset'])->end()
 									->scalarNode('name')->cannotBeEmpty()->defaultValue($defaults['edit']['view']['name'])->end()
 									->arrayNode('context')
 										->treatNullLike([])
@@ -269,6 +309,27 @@ class Configuration implements ConfigurationInterface {
 							->end()
 						->end()
 					->end()
+					->arrayNode('index')
+						->addDefaultsIfNotSet()
+						->children()
+							->arrayNode('route')
+								->treatNullLike([])
+								->defaultValue($defaults['index']['route'])
+								->scalarPrototype()->end()
+							->end()
+							->arrayNode('view')
+								->addDefaultsIfNotSet()
+								->children()
+									->scalarNode('name')->cannotBeEmpty()->defaultValue($defaults['index']['view']['name'])->end()
+									->arrayNode('context')
+										->treatNullLike([])
+										->defaultValue($defaults['index']['view']['context'])
+										->variablePrototype()->end()
+									->end()
+								->end()
+							->end()
+						->end()
+					->end()
 					->arrayNode('login')
 						->addDefaultsIfNotSet()
 						->children()
@@ -329,6 +390,16 @@ class Configuration implements ConfigurationInterface {
 					->arrayNode('register')
 						->addDefaultsIfNotSet()
 						->children()
+							->arrayNode('admin')
+								->treatNullLike([])
+								->defaultValue($defaults['edit']['admin'])
+								->variablePrototype()->end()
+							->end()
+							->arrayNode('field')
+								->treatNullLike([])
+								->defaultValue($defaults['register']['field'])
+								->variablePrototype()->end()
+							->end()
 							->arrayNode('route')
 								->treatNullLike([])
 								->defaultValue($defaults['register']['route'])
@@ -129,8 +144,8 @@ class Configuration implements ConfigurationInterface {
 		 * @link https://github.com/symfony/assetic-bundle/blob/master/DependencyInjection/Configuration.php#L63
 		 *
-		 * @see php bin/console config:dump-reference rapsys_user to dump default config
-		 * @see php bin/console debug:config rapsys_user to dump config
+		 * @see php bin/console config:dump-reference rapsysuser to dump default config
+		 * @see php bin/console debug:config rapsysuser to dump config
 		 */
 		$treeBuilder